@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2012 Sebastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -46,7 +46,7 @@ irc_display_hide_password (char *string, int look_for_nickserv)
 {
     char *pos_nickserv, *pos, *pos_pwd, *pos_space;
     int char_size;
-    
+
     pos = string;
     while (pos)
     {
@@ -110,7 +110,7 @@ irc_display_hide_password (char *string, int look_for_nickserv)
             {
                 pos_pwd++;
             }
-            
+
             while (pos_pwd && pos_pwd[0] && (pos_pwd[0] != ' '))
             {
                 char_size = weechat_utf8_char_size (pos_pwd);
@@ -132,7 +132,7 @@ irc_display_away (struct t_irc_server *server, const char *string1,
                   const char *string2)
 {
     struct t_irc_channel *ptr_channel;
-    
+
     for (ptr_channel = server->channels; ptr_channel;
          ptr_channel = ptr_channel->next_channel)
     {
@@ -144,7 +144,7 @@ irc_display_away (struct t_irc_server *server, const char *string1,
                                  IRC_COLOR_CHAT_DELIMITERS,
                                  IRC_COLOR_CHAT_NICK,
                                  server->nick,
-                                 IRC_COLOR_CHAT,
+                                 IRC_COLOR_RESET,
                                  string1,
                                  string2,
                                  IRC_COLOR_CHAT_DELIMITERS);
@@ -165,16 +165,15 @@ irc_display_server (struct t_irc_server *server, int with_detail)
     if (with_detail)
     {
         weechat_printf (NULL, "");
-        weechat_printf (NULL, _("%sServer: %s%s %s[%s%s%s]%s%s"),
-                        IRC_COLOR_CHAT,
+        weechat_printf (NULL, _("Server: %s%s %s[%s%s%s]%s%s"),
                         IRC_COLOR_CHAT_SERVER,
                         server->name,
                         IRC_COLOR_CHAT_DELIMITERS,
-                        IRC_COLOR_CHAT,
+                        IRC_COLOR_RESET,
                         (server->is_connected) ?
                         _("connected") : _("not connected"),
                         IRC_COLOR_CHAT_DELIMITERS,
-                        IRC_COLOR_CHAT,
+                        IRC_COLOR_RESET,
                         (server->temp_server) ? _(" (temporary)") : "");
         /* addresses */
         if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_ADDRESSES]))
@@ -220,6 +219,14 @@ irc_display_server (struct t_irc_server *server, int with_detail)
             weechat_printf (NULL, "  ssl_cert . . . . . . : %s'%s'",
                             IRC_COLOR_CHAT_VALUE,
                             weechat_config_string (server->options[IRC_SERVER_OPTION_SSL_CERT]));
+        /* ssl_priorities */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_SSL_PRIORITIES]))
+            weechat_printf (NULL, "  ssl_priorities . . . :   ('%s')",
+                            IRC_SERVER_OPTION_STRING(server, IRC_SERVER_OPTION_SSL_PRIORITIES));
+        else
+            weechat_printf (NULL, "  ssl_priorities . . . : %s'%s'",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_string (server->options[IRC_SERVER_OPTION_SSL_PRIORITIES]));
         /* ssl_dhkey_size */
         if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_SSL_DHKEY_SIZE]))
             weechat_printf (NULL, "  ssl_dhkey_size . . . :   (%d)",
@@ -246,6 +253,14 @@ irc_display_server (struct t_irc_server *server, int with_detail)
             weechat_printf (NULL, "  password . . . . . . : %s%s",
                             IRC_COLOR_CHAT_VALUE,
                             _("(hidden)"));
+        /* client capabilities */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_CAPABILITIES]))
+            weechat_printf (NULL, "  capabilities . . . . :   ('%s')",
+                            IRC_SERVER_OPTION_STRING(server, IRC_SERVER_OPTION_CAPABILITIES));
+        else
+            weechat_printf (NULL, "  capabilities . . . . : %s'%s'",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_string (server->options[IRC_SERVER_OPTION_CAPABILITIES]));
         /* sasl_mechanism */
         if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_SASL_MECHANISM]))
             weechat_printf (NULL, "  sasl_mechanism . . . :   ('%s')",
@@ -392,6 +407,70 @@ irc_display_server (struct t_irc_server *server, int with_detail)
                             IRC_COLOR_CHAT_VALUE,
                             weechat_config_integer (server->options[IRC_SERVER_OPTION_AUTOREJOIN_DELAY]),
                             NG_("second", "seconds", weechat_config_integer (server->options[IRC_SERVER_OPTION_AUTOREJOIN_DELAY])));
+        /* connection_timeout */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_CONNECTION_TIMEOUT]))
+            weechat_printf (NULL, "  connection_timeout . :   (%d %s)",
+                            IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_CONNECTION_TIMEOUT),
+                            NG_("second", "seconds", IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_CONNECTION_TIMEOUT)));
+        else
+            weechat_printf (NULL, "  connection_timeout . : %s%d %s",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_integer (server->options[IRC_SERVER_OPTION_CONNECTION_TIMEOUT]),
+                            NG_("second", "seconds", weechat_config_integer (server->options[IRC_SERVER_OPTION_CONNECTION_TIMEOUT])));
+        /* anti_flood_prio_high */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_HIGH]))
+            weechat_printf (NULL, "  anti_flood_prio_high :   (%d %s)",
+                            IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_HIGH),
+                            NG_("second", "seconds", IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_HIGH)));
+        else
+            weechat_printf (NULL, "  anti_flood_prio_high : %s%d %s",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_integer (server->options[IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_HIGH]),
+                            NG_("second", "seconds", weechat_config_integer (server->options[IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_HIGH])));
+        /* anti_flood_prio_low */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_LOW]))
+            weechat_printf (NULL, "  anti_flood_prio_low. :   (%d %s)",
+                            IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_LOW),
+                            NG_("second", "seconds", IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_LOW)));
+        else
+            weechat_printf (NULL, "  anti_flood_prio_low. : %s%d %s",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_integer (server->options[IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_LOW]),
+                            NG_("second", "seconds", weechat_config_integer (server->options[IRC_SERVER_OPTION_ANTI_FLOOD_PRIO_LOW])));
+        /* away_check */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_AWAY_CHECK]))
+            weechat_printf (NULL, "  away_check . . . . . :   (%d %s)",
+                            IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK),
+                            NG_("minute", "minutes", IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK)));
+        else
+            weechat_printf (NULL, "  away_check . . . . . : %s%d %s",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_integer (server->options[IRC_SERVER_OPTION_AWAY_CHECK]),
+                            NG_("minute", "minutes", weechat_config_integer (server->options[IRC_SERVER_OPTION_AWAY_CHECK])));
+        /* away_check_max_nicks */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS]))
+            weechat_printf (NULL, "  away_check_max_nicks :   (%d)",
+                            IRC_SERVER_OPTION_INTEGER(server, IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS));
+        else
+            weechat_printf (NULL, "  away_check_max_nicks : %s%d",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_integer (server->options[IRC_SERVER_OPTION_AWAY_CHECK_MAX_NICKS]));
+        /* default_msg_part */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_DEFAULT_MSG_PART]))
+            weechat_printf (NULL, "  default_msg_part . . :   ('%s')",
+                            IRC_SERVER_OPTION_STRING(server, IRC_SERVER_OPTION_DEFAULT_MSG_PART));
+        else
+            weechat_printf (NULL, "  default_msg_part . . : %s'%s'",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_string (server->options[IRC_SERVER_OPTION_DEFAULT_MSG_PART]));
+        /* default_msg_quit */
+        if (weechat_config_option_is_null (server->options[IRC_SERVER_OPTION_DEFAULT_MSG_QUIT]))
+            weechat_printf (NULL, "  default_msg_quit . . :   ('%s')",
+                            IRC_SERVER_OPTION_STRING(server, IRC_SERVER_OPTION_DEFAULT_MSG_QUIT));
+        else
+            weechat_printf (NULL, "  default_msg_quit . . : %s'%s'",
+                            IRC_COLOR_CHAT_VALUE,
+                            weechat_config_string (server->options[IRC_SERVER_OPTION_DEFAULT_MSG_QUIT]));
     }
     else
     {
@@ -404,11 +483,11 @@ irc_display_server (struct t_irc_server *server, int with_detail)
                             IRC_COLOR_CHAT_SERVER,
                             server->name,
                             IRC_COLOR_CHAT_DELIMITERS,
-                            IRC_COLOR_CHAT,
+                            IRC_COLOR_RESET,
                             (server->is_connected) ?
                             _("connected") : _("not connected"),
                             IRC_COLOR_CHAT_DELIMITERS,
-                            IRC_COLOR_CHAT,
+                            IRC_COLOR_RESET,
                             (server->temp_server) ? _(" (temporary)") : "",
                             num_channels,
                             NG_("channel", "channels", num_channels),
@@ -419,7 +498,7 @@ irc_display_server (struct t_irc_server *server, int with_detail)
             weechat_printf (NULL, "   %s%s%s%s",
                             IRC_COLOR_CHAT_SERVER,
                             server->name,
-                            IRC_COLOR_CHAT,
+                            IRC_COLOR_RESET,
                             (server->temp_server) ? _(" (temporary)") : "");
         }
     }
