@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2012 Sebastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -20,18 +20,13 @@
 #ifndef __WEECHAT_IRC_MODE_H
 #define __WEECHAT_IRC_MODE_H 1
 
-#define IRC_MODE_NICK_DEFAULT_PREFIXES_LIST "@%+~*&!-"
-
 struct t_irc_server;
 struct t_irc_channel;
 
 extern int irc_mode_channel_set (struct t_irc_server *server,
                                  struct t_irc_channel *channel,
                                  const char *modes);
-extern void irc_mode_user_set (struct t_irc_server *server, const char *modes);
-extern int irc_mode_get_nick_attr (struct t_irc_server *server, char *mode,
-                                   char prefix);
-extern char irc_mode_get_prefix (struct t_irc_server *server, char mode,
-                                 char default_prefix);
+extern void irc_mode_user_set (struct t_irc_server *server, const char *modes,
+                               int reset_modes);
 
 #endif /* __WEECHAT_IRC_MODE_H */
