@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2012 Sebastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -50,7 +50,7 @@ void
 script_config_read (struct t_weechat_plugin *weechat_plugin)
 {
     const char *string;
-    
+
     string = weechat_config_get_plugin (SCRIPT_OPTION_CHECK_LICENSE);
     if (!string)
     {
@@ -73,106 +73,12 @@ script_config_cb (void *data, const char *option, const char *value)
     /* make C compiler happy */
     (void) option;
     (void) value;
-    
+
     script_config_read (data);
-    
+
     return WEECHAT_RC_OK;
 }
 
-/*
- * script_upgrade_set_buffer_callbacks: restore buffers callbacks (input and
- *                                      close) for buffers created by script
- *                                      plugin
- */
-
-void
-script_upgrade_set_buffer_callbacks (struct t_weechat_plugin *weechat_plugin,
-                                     struct t_plugin_script **scripts,
-                                     int (*callback_buffer_input) (void *data,
-                                                                   struct t_gui_buffer *buffer,
-                                                                   const char *input_data),
-                                     int (*callback_buffer_close) (void *data,
-                                                                   struct t_gui_buffer *buffer))
-{
-    struct t_infolist *infolist;
-    struct t_gui_buffer *ptr_buffer;
-    const char *script_name, *script_input_cb, *script_input_cb_data;
-    const char *script_close_cb, *script_close_cb_data;
-    struct t_plugin_script *ptr_script;
-    struct t_script_callback *new_script_callback_input;
-    struct t_script_callback *new_script_callback_close;
-    
-    infolist = weechat_infolist_get ("buffer", NULL, NULL);
-    if (infolist)
-    {
-        while (weechat_infolist_next (infolist))
-        {
-            if (weechat_infolist_pointer (infolist, "plugin") == weechat_plugin)
-            {
-                ptr_buffer = weechat_infolist_pointer (infolist, "pointer");
-                script_name = weechat_buffer_get_string (ptr_buffer, "localvar_script_name");
-                if (script_name && script_name[0])
-                {
-                    ptr_script = script_search (weechat_plugin, *scripts,
-                                                script_name);
-                    if (ptr_script)
-                    {
-                        script_input_cb = weechat_buffer_get_string (ptr_buffer,
-                                                                     "localvar_script_input_cb");
-                        script_input_cb_data = weechat_buffer_get_string (ptr_buffer,
-                                                                          "localvar_script_input_cb_data");
-                        script_close_cb = weechat_buffer_get_string (ptr_buffer,
-                                                                     "localvar_script_close_cb");
-                        script_close_cb_data = weechat_buffer_get_string (ptr_buffer,
-                                                                          "localvar_script_close_cb_data");
-                        
-                        if (script_input_cb && script_input_cb[0])
-                        {
-                            new_script_callback_input = script_callback_alloc ();
-                            if (new_script_callback_input)
-                            {
-                                script_callback_init (new_script_callback_input,
-                                                      ptr_script,
-                                                      script_input_cb,
-                                                      script_input_cb_data);
-                                new_script_callback_input->buffer = ptr_buffer;
-                                script_callback_add (ptr_script,
-                                                     new_script_callback_input);
-                                weechat_buffer_set_pointer (ptr_buffer,
-                                                            "input_callback",
-                                                            callback_buffer_input);
-                                weechat_buffer_set_pointer (ptr_buffer,
-                                                            "input_callback_data",
-                                                            new_script_callback_input);
-                            }
-                        }
-                        if (script_close_cb && script_close_cb[0])
-                        {
-                            new_script_callback_close = script_callback_alloc ();
-                            if (new_script_callback_close)
-                            {
-                                script_callback_init (new_script_callback_close,
-                                                      ptr_script,
-                                                      script_close_cb,
-                                                      script_close_cb_data);
-                                new_script_callback_close->buffer = ptr_buffer;
-                                script_callback_add (ptr_script,
-                                                     new_script_callback_close);
-                                weechat_buffer_set_pointer (ptr_buffer,
-                                                            "close_callback",
-                                                            callback_buffer_close);
-                                weechat_buffer_set_pointer (ptr_buffer,
-                                                            "close_callback_data",
-                                                            new_script_callback_close);
-                            }
-                        }
-                    }
-                }
-            }
-        }
-    }
-}
-
 /*
  * script_init: initialize script plugin
  */
@@ -181,7 +87,6 @@ void
 script_init (struct t_weechat_plugin *weechat_plugin,
              int argc,
              char *argv[],
-             struct t_plugin_script **scripts,
              int (*callback_command)(void *data,
                                      struct t_gui_buffer *buffer,
                                      int argc, char **argv,
@@ -202,20 +107,15 @@ script_init (struct t_weechat_plugin *weechat_plugin,
              int (*callback_signal_script_action)(void *data, const char *signal,
                                                   const char *type_data,
                                                   void *signal_data),
-             void (*callback_load_file)(void *data, const char *filename),
-             int (*callback_buffer_input) (void *data,
-                                           struct t_gui_buffer *buffer,
-                                           const char *input_data),
-             int (*callback_buffer_close) (void *data,
-                                           struct t_gui_buffer *buffer))
+             void (*callback_load_file)(void *data, const char *filename))
 {
     char *string, *completion;
     char signal_name[128];
-    int length, i, upgrading, auto_load_scripts;
-    
+    int length, i, auto_load_scripts;
+
     /* read script configuration */
     script_config_read (weechat_plugin);
-    
+
     /* add hook for config option */
     length = strlen (weechat_plugin->name) + 64;
     string = malloc (length);
@@ -226,7 +126,7 @@ script_init (struct t_weechat_plugin *weechat_plugin,
         weechat_hook_config (string, &script_config_cb, weechat_plugin);
         free (string);
     }
-    
+
     /* create directories in WeeChat home */
     weechat_mkdir_home (weechat_plugin->name, 0755);
     length = strlen (weechat_plugin->name) + strlen ("/autoload") + 1;
@@ -237,7 +137,7 @@ script_init (struct t_weechat_plugin *weechat_plugin,
         weechat_mkdir_home (string, 0755);
         free (string);
     }
-    
+
     /* add command */
     completion = NULL;
     length = strlen (weechat_plugin->name) + 16;
@@ -257,11 +157,23 @@ script_init (struct t_weechat_plugin *weechat_plugin,
     }
     weechat_hook_command (weechat_plugin->name,
                           N_("list/load/unload scripts"),
-                          N_("[list [name]] | [listfull [name]] | "
-                             "[load filename] | [autoload] | "
-                             "[reload [name]] | [unload [name]]"),
-                          N_("filename: script (file) to load\n"
-                             "name: a script name\n\n"
+                          N_("list|listfull [<name>]"
+                             " || load <filename>"
+                             " || autoload"
+                             " || reload|unload [<name>]"),
+                          N_("    list: list loaded scripts\n"
+                             "listfull: list loaded scripts (verbose)\n"
+                             "    load: load a script\n"
+                             "autoload: load all scripts in \"autoload\" "
+                             "directory\n"
+                             "  reload: reload a script (if no name given, "
+                             "unload all scripts, then load all scripts in "
+                             "\"autoload\" directory)\n"
+                             "  unload: unload a script (if no name given, "
+                             "unload all scripts)\n"
+                             "filename: script (file) to load\n"
+                             "    name: a script name (name used in call to "
+                             "\"register\" function)\n\n"
                              "Without argument, this command "
                              "lists all loaded scripts."),
                           completion,
@@ -270,7 +182,7 @@ script_init (struct t_weechat_plugin *weechat_plugin,
         free (string);
     if (completion)
         free (completion);
-    
+
     /* add completion and infolist */
     length = strlen (weechat_plugin->name) + 16;
     string = malloc (length);
@@ -285,13 +197,13 @@ script_init (struct t_weechat_plugin *weechat_plugin,
                                callback_infolist, NULL);
         free (string);
     }
-    
+
     /* add signal for "debug_dump" */
     weechat_hook_signal ("debug_dump", callback_signal_debug_dump, NULL);
-    
+
     /* add signal for "buffer_closed" */
     weechat_hook_signal ("buffer_closed", callback_signal_buffer_closed, NULL);
-    
+
     /* add signal for a script action (install/remove) */
     snprintf (signal_name, sizeof (signal_name), "%s_script_install",
               weechat_plugin->name);
@@ -299,37 +211,23 @@ script_init (struct t_weechat_plugin *weechat_plugin,
     snprintf (signal_name, sizeof (signal_name), "%s_script_remove",
               weechat_plugin->name);
     weechat_hook_signal (signal_name, callback_signal_script_action, NULL);
-    
+
     /* parse arguments */
-    upgrading = 0;
     auto_load_scripts = 1;
     for (i = 0; i < argc; i++)
     {
-        if (strcmp (argv[i], "--upgrade") == 0)
-        {
-            upgrading = 1;
-        }
-        else if ((strcmp (argv[i], "-s") == 0)
+        if ((strcmp (argv[i], "-s") == 0)
                  || (strcmp (argv[i], "--no-script") == 0))
         {
             auto_load_scripts = 0;
         }
     }
-    
+
     /* autoload scripts */
     if (auto_load_scripts)
     {
         script_auto_load (weechat_plugin, callback_load_file);
     }
-    
-    /* set buffer callbacks after upgrade */
-    if (upgrading)
-    {
-        script_upgrade_set_buffer_callbacks (weechat_plugin,
-                                             scripts,
-                                             callback_buffer_input,
-                                             callback_buffer_close);
-    }
 }
 
 /*
@@ -343,17 +241,17 @@ script_valid (struct t_plugin_script *scripts,
               struct t_plugin_script *script)
 {
     struct t_plugin_script *ptr_script;
-    
+
     if (!script)
         return 0;
-    
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
         if (ptr_script == script)
             return 1;
     }
-    
+
     /* script not found */
     return 0;
 }
@@ -368,13 +266,13 @@ char *
 script_ptr2str (void *pointer)
 {
     char pointer_str[128];
-    
+
     if (!pointer)
         return strdup ("");
-    
+
     snprintf (pointer_str, sizeof (pointer_str),
               "0x%lx", (long unsigned int)pointer);
-    
+
     return strdup (pointer_str);
 }
 
@@ -386,13 +284,16 @@ void *
 script_str2ptr (const char *pointer_str)
 {
     long unsigned int value;
-    
+    int rc;
+
     if (!pointer_str || (pointer_str[0] != '0') || (pointer_str[1] != 'x'))
         return NULL;
-    
-    sscanf (pointer_str + 2, "%lx", &value);
-    
-    return (void *)value;
+
+    rc = sscanf (pointer_str + 2, "%lx", &value);
+    if ((rc != EOF) && (rc >= 1))
+        return (void *)value;
+
+    return NULL;
 }
 
 /*
@@ -406,7 +307,7 @@ script_auto_load (struct t_weechat_plugin *weechat_plugin,
     const char *dir_home;
     char *dir_name;
     int dir_length;
-    
+
     /* build directory, adding WeeChat home */
     dir_home = weechat_info_get ("weechat_dir", "");
     if (!dir_home)
@@ -415,11 +316,11 @@ script_auto_load (struct t_weechat_plugin *weechat_plugin,
     dir_name = malloc (dir_length);
     if (!dir_name)
         return;
-    
+
     snprintf (dir_name, dir_length,
               "%s/%s/autoload", dir_home, weechat_plugin->name);
     weechat_exec_on_files (dir_name, 0, NULL, callback);
-    
+
     free (dir_name);
 }
 
@@ -432,14 +333,14 @@ script_search (struct t_weechat_plugin *weechat_plugin,
                struct t_plugin_script *scripts, const char *name)
 {
     struct t_plugin_script *ptr_script;
-    
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
         if (weechat_strcasecmp (ptr_script->name, name) == 0)
             return ptr_script;
     }
-    
+
     /* script not found */
     return NULL;
 }
@@ -455,7 +356,7 @@ script_search_by_full_name (struct t_plugin_script *scripts,
 {
     char *base_name;
     struct t_plugin_script *ptr_script;
-    
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
@@ -463,7 +364,7 @@ script_search_by_full_name (struct t_plugin_script *scripts,
         if (strcmp (base_name, full_name) == 0)
             return ptr_script;
     }
-    
+
     /* script not found */
     return NULL;
 }
@@ -480,10 +381,10 @@ script_search_path (struct t_weechat_plugin *weechat_plugin,
     const char *dir_home, *dir_system;
     int length;
     struct stat st;
-    
+
     if (filename[0] == '~')
         return weechat_string_expand_home (filename);
-    
+
     dir_home = weechat_info_get ("weechat_dir", "");
     if (dir_home)
     {
@@ -513,7 +414,7 @@ script_search_path (struct t_weechat_plugin *weechat_plugin,
                 return final_name;
             free (final_name);
         }
-        
+
         /* try WeeChat user's dir */
         length = strlen (dir_home) + strlen (filename) + 16;
         final_name = malloc (length);
@@ -526,7 +427,7 @@ script_search_path (struct t_weechat_plugin *weechat_plugin,
             free (final_name);
         }
     }
-    
+
     /* try WeeChat system dir */
     dir_system = weechat_info_get ("weechat_sharedir", "");
     if (dir_system)
@@ -543,7 +444,7 @@ script_search_path (struct t_weechat_plugin *weechat_plugin,
             free (final_name);
         }
     }
-    
+
     return strdup (filename);
 }
 
@@ -625,7 +526,7 @@ script_add (struct t_weechat_plugin *weechat_plugin,
             const char *charset)
 {
     struct t_plugin_script *new_script;
-    
+
     if (strchr (name, ' '))
     {
         weechat_printf (NULL,
@@ -634,7 +535,7 @@ script_add (struct t_weechat_plugin *weechat_plugin,
                         weechat_plugin->name, name);
         return NULL;
     }
-    
+
     if (script_option_check_license
         && (weechat_strcmp_ignore_chars (weechat_plugin->license, license,
                                          "0123456789-.,/\\()[]{}", 0) != 0))
@@ -645,7 +546,7 @@ script_add (struct t_weechat_plugin *weechat_plugin,
                         weechat_prefix ("error"), weechat_plugin->name,
                         license, name, weechat_plugin->license);
     }
-    
+
     new_script = malloc (sizeof (*new_script));
     if (new_script)
     {
@@ -660,19 +561,115 @@ script_add (struct t_weechat_plugin *weechat_plugin,
             strdup (shutdown_func) : NULL;
         new_script->charset = (charset) ? strdup (charset) : NULL;
         new_script->callbacks = NULL;
-        
+
         script_insert_sorted (weechat_plugin, scripts, last_script, new_script);
-        
+
         return new_script;
     }
-    
+
     weechat_printf (NULL,
                     _("%s: error loading script \"%s\" (not enough memory)"),
                     weechat_plugin->name, name);
-    
+
     return NULL;
 }
 
+/*
+ * script_set_buffer_callbacks: restore buffers callbacks (input and
+ *                              close) for buffers created by script
+ *                              plugin
+ */
+
+void
+script_set_buffer_callbacks (struct t_weechat_plugin *weechat_plugin,
+                             struct t_plugin_script *scripts,
+                             struct t_plugin_script *script,
+                             int (*callback_buffer_input) (void *data,
+                                                           struct t_gui_buffer *buffer,
+                                                           const char *input_data),
+                             int (*callback_buffer_close) (void *data,
+                                                           struct t_gui_buffer *buffer))
+{
+    struct t_infolist *infolist;
+    struct t_gui_buffer *ptr_buffer;
+    const char *script_name, *script_input_cb, *script_input_cb_data;
+    const char *script_close_cb, *script_close_cb_data;
+    struct t_plugin_script *ptr_script;
+    struct t_script_callback *new_script_callback_input;
+    struct t_script_callback *new_script_callback_close;
+
+    infolist = weechat_infolist_get ("buffer", NULL, NULL);
+    if (infolist)
+    {
+        while (weechat_infolist_next (infolist))
+        {
+            if (weechat_infolist_pointer (infolist, "plugin") == weechat_plugin)
+            {
+                ptr_buffer = weechat_infolist_pointer (infolist, "pointer");
+                script_name = weechat_buffer_get_string (ptr_buffer, "localvar_script_name");
+                if (script_name && script_name[0])
+                {
+                    ptr_script = script_search (weechat_plugin, scripts,
+                                                script_name);
+                    if (ptr_script && (ptr_script == script))
+                    {
+                        script_input_cb = weechat_buffer_get_string (ptr_buffer,
+                                                                     "localvar_script_input_cb");
+                        script_input_cb_data = weechat_buffer_get_string (ptr_buffer,
+                                                                          "localvar_script_input_cb_data");
+                        script_close_cb = weechat_buffer_get_string (ptr_buffer,
+                                                                     "localvar_script_close_cb");
+                        script_close_cb_data = weechat_buffer_get_string (ptr_buffer,
+                                                                          "localvar_script_close_cb_data");
+
+                        if (script_input_cb && script_input_cb[0])
+                        {
+                            new_script_callback_input = script_callback_alloc ();
+                            if (new_script_callback_input)
+                            {
+                                script_callback_init (new_script_callback_input,
+                                                      ptr_script,
+                                                      script_input_cb,
+                                                      script_input_cb_data);
+                                new_script_callback_input->buffer = ptr_buffer;
+                                script_callback_add (ptr_script,
+                                                     new_script_callback_input);
+                                weechat_buffer_set_pointer (ptr_buffer,
+                                                            "input_callback",
+                                                            callback_buffer_input);
+                                weechat_buffer_set_pointer (ptr_buffer,
+                                                            "input_callback_data",
+                                                            new_script_callback_input);
+                            }
+                        }
+                        if (script_close_cb && script_close_cb[0])
+                        {
+                            new_script_callback_close = script_callback_alloc ();
+                            if (new_script_callback_close)
+                            {
+                                script_callback_init (new_script_callback_close,
+                                                      ptr_script,
+                                                      script_close_cb,
+                                                      script_close_cb_data);
+                                new_script_callback_close->buffer = ptr_buffer;
+                                script_callback_add (ptr_script,
+                                                     new_script_callback_close);
+                                weechat_buffer_set_pointer (ptr_buffer,
+                                                            "close_callback",
+                                                            callback_buffer_close);
+                                weechat_buffer_set_pointer (ptr_buffer,
+                                                            "close_callback_data",
+                                                            new_script_callback_close);
+                            }
+                        }
+                    }
+                }
+            }
+        }
+        weechat_infolist_free (infolist);
+    }
+}
+
 /*
  * script_remove_buffer_callbacks: remove callbacks for a buffer (called when a
  *                                 buffer is closed by user)
@@ -684,7 +681,7 @@ script_remove_buffer_callbacks (struct t_plugin_script *scripts,
 {
     struct t_plugin_script *ptr_script;
     struct t_script_callback *ptr_script_callback, *next_script_callback;
-    
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
@@ -692,10 +689,10 @@ script_remove_buffer_callbacks (struct t_plugin_script *scripts,
         while (ptr_script_callback)
         {
             next_script_callback = ptr_script_callback->next_callback;
-            
+
             if (ptr_script_callback->buffer == buffer)
                 script_callback_remove (ptr_script, ptr_script_callback);
-            
+
             ptr_script_callback = next_script_callback;
         }
     }
@@ -712,7 +709,7 @@ script_remove (struct t_weechat_plugin *weechat_plugin,
                struct t_plugin_script *script)
 {
     struct t_script_callback *ptr_script_callback, *next_script_callback;
-    
+
     for (ptr_script_callback = script->callbacks; ptr_script_callback;
          ptr_script_callback = ptr_script_callback->next_callback)
     {
@@ -722,12 +719,12 @@ script_remove (struct t_weechat_plugin *weechat_plugin,
             weechat_unhook (ptr_script_callback->hook);
         }
     }
-    
+
     ptr_script_callback = script->callbacks;
     while (ptr_script_callback)
     {
         next_script_callback = ptr_script_callback->next_callback;
-        
+
         /* free config file */
         if (ptr_script_callback->config_file
             && !ptr_script_callback->config_section
@@ -737,11 +734,11 @@ script_remove (struct t_weechat_plugin *weechat_plugin,
                 weechat_config_write (ptr_script_callback->config_file);
             weechat_config_free (ptr_script_callback->config_file);
         }
-        
+
         /* remove bar item */
         if (ptr_script_callback->bar_item)
             weechat_bar_item_remove (ptr_script_callback->bar_item);
-        
+
         /* remove buffer */
         if (ptr_script_callback->buffer)
         {
@@ -754,13 +751,13 @@ script_remove (struct t_weechat_plugin *weechat_plugin,
             }
             weechat_buffer_close (ptr_script_callback->buffer);
         }
-        
+
         ptr_script_callback = next_script_callback;
     }
-    
+
     /* remove all callbacks created by this script */
     script_callback_remove_all (script);
-    
+
     /* free data */
     if (script->filename)
         free (script->filename);
@@ -778,7 +775,7 @@ script_remove (struct t_weechat_plugin *weechat_plugin,
         free (script->shutdown_func);
     if (script->charset)
         free (script->charset);
-    
+
     /* remove script from list */
     if (script->prev_script)
         (script->prev_script)->next_script = script->next_script;
@@ -788,7 +785,7 @@ script_remove (struct t_weechat_plugin *weechat_plugin,
         *scripts = script->next_script;
     if (*last_script == script)
         *last_script = script->prev_script;
-    
+
     /* free script */
     free (script);
 }
@@ -820,9 +817,10 @@ void
 script_action_add (char **action_list, const char *name)
 {
     int length;
+    char *action_list2;
 
     length = strlen (name);
-    
+
     if (!(*action_list))
     {
         *action_list = malloc (length + 1);
@@ -831,13 +829,17 @@ script_action_add (char **action_list, const char *name)
     }
     else
     {
-        *action_list = realloc (*action_list,
+        action_list2 = realloc (*action_list,
                                 strlen (*action_list) + 1 + length + 1);
-        if (*action_list)
+        if (!action_list2)
         {
-            strcat (*action_list, ",");
-            strcat (*action_list, name);
+            free (*action_list);
+            *action_list = NULL;
+            return;
         }
+        *action_list = action_list2;
+        strcat (*action_list, ",");
+        strcat (*action_list, name);
     }
 }
 
@@ -851,7 +853,7 @@ script_remove_file (struct t_weechat_plugin *weechat_plugin, const char *name,
 {
     int num_found, i;
     char *path_script;
-    
+
     num_found = 0;
     i = 0;
     while (i < 2)
@@ -911,9 +913,9 @@ script_action_install (struct t_weechat_plugin *weechat_plugin,
     char **argv, *name, *ptr_base_name, *base_name, *new_path, *autoload_path;
     char *symlink_path;
     const char *dir_home, *dir_separator;
-    int argc, i, length;
+    int argc, i, length, rc;
     struct t_plugin_script *ptr_script;
-    
+
     if (*list)
     {
         argv = weechat_string_split (*list, ",", 0, 0, &argc);
@@ -932,10 +934,10 @@ script_action_install (struct t_weechat_plugin *weechat_plugin,
                         ptr_script = script_search_by_full_name (scripts, base_name);
                         if (ptr_script)
                             (*script_unload) (ptr_script);
-                        
+
                         /* remove script file(s) */
                         script_remove_file (weechat_plugin, base_name, 0);
-                        
+
                         /* move file from install dir to language dir */
                         dir_home = weechat_info_get ("weechat_dir", "");
                         length = strlen (dir_home) + strlen (weechat_plugin->name) +
@@ -966,12 +968,13 @@ script_action_install (struct t_weechat_plugin *weechat_plugin,
                                     {
                                         snprintf (symlink_path, length, "..%s%s",
                                                   dir_separator, base_name);
-                                        symlink (symlink_path, autoload_path);
+                                        rc = symlink (symlink_path, autoload_path);
+                                        (void) rc;
                                         free (symlink_path);
                                     }
                                     free (autoload_path);
                                 }
-                                
+
                                 /* load script */
                                 (*script_load) (new_path);
                             }
@@ -1016,7 +1019,7 @@ script_action_remove (struct t_weechat_plugin *weechat_plugin,
     char **argv;
     int argc, i;
     struct t_plugin_script *ptr_script;
-    
+
     if (*list)
     {
         argv = weechat_string_split (*list, ",", 0, 0, &argc);
@@ -1028,7 +1031,7 @@ script_action_remove (struct t_weechat_plugin *weechat_plugin,
                 ptr_script = script_search_by_full_name (scripts, argv[i]);
                 if (ptr_script)
                     (*script_unload) (ptr_script);
-                
+
                 /* remove script file(s) */
                 script_remove_file (weechat_plugin, argv[i], 1);
             }
@@ -1049,7 +1052,7 @@ script_display_list (struct t_weechat_plugin *weechat_plugin,
                      const char *name, int full)
 {
     struct t_plugin_script *ptr_script;
-    
+
     weechat_printf (NULL, "");
     weechat_printf (NULL,
                     /* TRANSLATORS: "%s" is language (for example "perl") */
@@ -1098,21 +1101,21 @@ script_display_short_list (struct t_weechat_plugin *weechat_plugin,
     char *buf;
     int length;
     struct t_plugin_script *ptr_script;
-    
+
     if (scripts)
     {
         /* TRANSLATORS: "%s" is language (for example "perl") */
         scripts_loaded = _("%s scripts loaded:");
-        
+
         length = strlen (scripts_loaded) + strlen (weechat_plugin->name) + 1;
-        
+
         for (ptr_script = scripts; ptr_script;
              ptr_script = ptr_script->next_script)
         {
             length += strlen (ptr_script->name) + 2;
         }
         length++;
-        
+
         buf = malloc (length);
         if (buf)
         {
@@ -1142,14 +1145,14 @@ script_add_to_infolist (struct t_weechat_plugin *weechat_plugin,
                         struct t_plugin_script *script)
 {
     struct t_infolist_item *ptr_item;
-    
+
     if (!infolist || !script)
         return 0;
-    
+
     ptr_item = weechat_infolist_new_item (infolist);
     if (!ptr_item)
         return 0;
-    
+
     if (!weechat_infolist_new_var_pointer (ptr_item, "pointer", script))
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "filename", script->filename))
@@ -1170,7 +1173,7 @@ script_add_to_infolist (struct t_weechat_plugin *weechat_plugin,
         return 0;
     if (!weechat_infolist_new_var_string (ptr_item, "charset", script->charset))
         return 0;
-    
+
     return 1;
 }
 
@@ -1186,10 +1189,10 @@ script_infolist_list_scripts (struct t_weechat_plugin *weechat_plugin,
 {
     struct t_infolist *ptr_infolist;
     struct t_plugin_script *ptr_script;
-    
+
     if (pointer && !script_valid (scripts, pointer))
         return NULL;
-    
+
     ptr_infolist = weechat_infolist_new ();
     if (ptr_infolist)
     {
@@ -1224,7 +1227,7 @@ script_infolist_list_scripts (struct t_weechat_plugin *weechat_plugin,
             return ptr_infolist;
         }
     }
-    
+
     return NULL;
 }
 
@@ -1238,11 +1241,11 @@ script_end (struct t_weechat_plugin *weechat_plugin,
             void (*callback_unload_all)())
 {
     int scripts_loaded;
-    
+
     scripts_loaded = (*scripts) ? 1 : 0;
-    
+
     (void)(callback_unload_all) ();
-    
+
     if (scripts_loaded)
     {
         weechat_printf (NULL, _("%s: scripts unloaded"),
@@ -1260,11 +1263,11 @@ script_print_log (struct t_weechat_plugin *weechat_plugin,
 {
     struct t_plugin_script *ptr_script;
     struct t_script_callback *ptr_script_callback;
-    
+
     weechat_log_printf ("");
     weechat_log_printf ("***** \"%s\" plugin dump *****",
                         weechat_plugin->name);
-    
+
     for (ptr_script = scripts; ptr_script;
          ptr_script = ptr_script->next_script)
     {
@@ -1289,7 +1292,7 @@ script_print_log (struct t_weechat_plugin *weechat_plugin,
             script_callback_print_log (weechat_plugin, ptr_script_callback);
         }
     }
-    
+
     weechat_log_printf ("");
     weechat_log_printf ("***** End of \"%s\" plugin dump *****",
                         weechat_plugin->name);
